@@ -44,6 +44,18 @@ sub _encode_cb {
     return $self->{_encode_cb};
 }
 
+sub _item_idx
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_item_idx} = shift;
+    }
+
+    return $self->{_item_idx};
+}
+
 sub _initialize {
     my $self = shift;
     my $args = shift;
@@ -59,6 +71,8 @@ sub _initialize {
         $self->_encode_cb(\&_default_encode);
     }
 
+    $self->_item_idx(-1);
+
     return 0;
 }
 
@@ -112,7 +126,7 @@ sub _out_tag {
     my $attr    = "";
     if (ref($inner) eq 'HASH') {
         my %inner_copy = %$inner;
-        $content = delete $inner_copy{content}; 
+        $content = delete $inner_copy{content};
         foreach my $key (keys %inner_copy) {
             my $value = $inner->{$key};
             if (defined($value)) {
@@ -144,7 +158,7 @@ sub _out_ns_tag {
         foreach my $attr (sort { $a cmp $b } keys(%{$inner}))
         {
             $self->_out(
-                  q{ } 
+                  q{ }
                 . $self->_sanitize($attr)
                 . q{="}
                 . $self->_encode($inner->{$attr})
@@ -242,9 +256,9 @@ sub _get_top_elem_about {
 
 sub _start_top_elem {
     my ($self, $tag, $about_sub) = @_;
-    
+
     my $about = $self->_get_top_elem_about($tag, $about_sub);
-    
+
     return $self->_out("<$tag$about>\n");
 }
 
@@ -261,7 +275,7 @@ sub _output_complete_textinput {
     my $master_tag = $self->_get_textinput_tag();
 
     if (defined(my $link = $self->textinput('link'))) {
-        $self->_start_top_elem($master_tag, 
+        $self->_start_top_elem($master_tag,
             sub { $link }
         );
 
@@ -497,9 +511,22 @@ sub _out_item_desc {
 sub _output_common_item_tags {
     my ($self, $item) = @_;
 
+    my @fields = (qw( title link ));
+
+    my $defined = $self->_get_item_defined;
+
+    if (! $defined) {
+        foreach my $f (@fields)
+        {
+            if (!defined($item->{$f})) {
+                die qq/Item No. / . $self->_item_idx() . qq/ is missing the "$f" field./;
+            }
+        }
+    }
+
     $self->_output_multiple_tags(
-        {ext => $item, 'defined' => $self->_get_item_defined},
-        [qw(title link)],);
+        {ext => $item, type => 'item', idx => $self->_item_idx(), 'defined' => $defined,},
+        [@fields],);
 
     $self->_out_item_desc($item);
 
@@ -662,7 +689,7 @@ sub _out_module_prefix_elements_hash
     my $prefix = $args->{prefix};
     my $data = $args->{data};
     my $url = $args->{url};
-    
+
     while (my ($el, $value) = each(%$data)) {
         $self->_out_module_prefix_pair(
             {
@@ -682,7 +709,7 @@ sub _out_module_prefix_pair
 
     my $prefix = $args->{prefix};
     my $url = $args->{url};
-    
+
     my $el = $args->{el};
     my $value = $args->{val};
 
@@ -747,7 +774,7 @@ sub _out_modules_elements {
     # Ad-hoc modules
     while (my ($url, $prefix) = each %{$self->_modules}) {
         next if $prefix =~ /^(dc|syn|taxo)$/;
-        
+
         $self->_out_module_prefix_elements(
             {
                 prefix => $prefix,
@@ -849,11 +876,22 @@ sub _out_seq_items {
     # Seq items
     $self->_out("<items>\n <rdf:Seq>\n");
 
+    my $idx = 0;
     foreach my $item (@{$self->_main->_get_items()}) {
+
+        my $about_text = $self->_get_item_about($item);
+
+        if (!defined($about_text)) {
+            die qq/Item No. $idx is missing "about" or "link" fields./;
+        }
+
         $self->_out('  <rdf:li rdf:resource="' .
-            $self->_encode($self->_get_item_about($item)) .
+            $self->_encode($about_text) .
             '" />' . "\n");
     }
+    continue {
+        $idx++;
+    }
 
     $self->_out(" </rdf:Seq>\n</items>\n");
 }
@@ -871,7 +909,7 @@ sub _get_rdf_decl_mappings
     return
     [
         $self->_get_first_rdf_decl_mappings(),
-        map { [$modules->{$_}, $_] } keys(%$modules)
+        sort { $a->[0] cmp $b->[0] } map { [$modules->{$_}, $_] } keys(%$modules)
     ];
 }
 
@@ -879,14 +917,14 @@ sub _render_xmlns {
     my ($self, $prefix, $url) = @_;
 
     my $pp = defined($prefix) ? ":$prefix" : "";
-    
+
     return qq{ xmlns$pp="$url"\n};
 }
 
 sub _get_rdf_xmlnses {
     my $self = shift;
 
-    return 
+    return
         join("",
             map { $self->_render_xmlns(@$_) }
             @{$self->_get_rdf_decl_mappings}
@@ -1000,9 +1038,13 @@ sub _output_single_item {
 sub _output_items {
     my $self = shift;
 
+    $self->_item_idx(0);
     foreach my $item (@{$self->_get_filtered_items}) {
         $self->_output_single_item($item);
     }
+    continue {
+        $self->_item_idx($self->_item_idx()+1);
+    }
 }
 
 sub _output_main_elements {
@@ -1087,7 +1129,7 @@ sub _out_dates {
 sub _out_def_chan_tag {
     my ($self, $tag) = @_;
     return $self->_output_multiple_tags(
-        {ext => "channel", 'defined' => 1}, 
+        {ext => "channel", 'defined' => 1},
         [ $tag ],
     );
 }
